@@ -1,7 +1,7 @@
 /* commands.c -- 
  *
  * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998, 1999, 2000 Martin Hedenfalk
+ * This program is Copyright (C) 1998-2001 martin HedenfaLk
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -448,7 +448,7 @@ void cmd_cd(int argc, char **argv)
 	maxargs(optind);
 #endif
 
-	maxargs(1);
+	maxargs_nohelp(1);
 	need_connected();
 	need_loggedin();
 
@@ -712,10 +712,10 @@ void cmd_site(int argc, char **argv)
 			 "try 'site help' or 'rhelp site' for more information\n");
 #endif
 
-	minargs(optind);
+	minargs_nohelp(1);
 	need_connected();
 
-	e = args_cat(argc, argv, optind);
+	e = args_cat(argc, argv, 1);
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("SITE %s", e);
 	xfree(e);
