@@ -1,7 +1,7 @@
 /* commands.h -- 
  * 
  * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998, 1999, 2000 Martin Hedenfalk
+ * This program is Copyright (C) 1998-2001 martin HedenfaLk
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,12 +35,27 @@
     return; \
   }
 
+#define maxargs_nohelp(n) \
+  if(argc > n+1) { \
+    char *fooargs; \
+    fooargs = args_cat(argc, argv, n+1); \
+    fprintf(stderr, _("unexpected arguments -- '%s', try 'help %s' for more information\n"), fooargs, argv[0]); \
+    xfree(fooargs); \
+    return; \
+  }
+
 #define minargs(n) \
   if(argc <= n) { \
     fprintf(stderr, _("missing argument, try '%s --help' for more information\n"), argv[0]); \
     return; \
   }
 
+#define minargs_nohelp(n) \
+  if(argc <= n) { \
+    fprintf(stderr, _("missing argument, try 'help %s' for more information\n"), argv[0]); \
+    return; \
+  }
+
 #define need_connected() \
   if(!ftp_connected()) { \
     fprintf(stderr, _("Not connected. Try 'open --help' for more information.\n")); \
