@@ -1,7 +1,7 @@
 /* help.c -- local help and info
  * 
  * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998, 1999, 2000 Martin Hedenfalk
+ * This program is Copyright (C) 1998-2001 martin HedenfaLk
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,8 +69,9 @@ void cmd_help(int argc, char **argv)
 		func = rl_named_function("possible-completions");
 		if(func)
 			func();
-		else {
+		else
 #endif
+		{
 			for(i=0;cmds[i].cmd;i++)
 				printf("%s\n", cmds[i].cmd);
 			{
