@@ -1,7 +1,7 @@
 /* login.c -- connect and login
  * 
  * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998, 1999, 2000 Martin Hedenfalk
+ * This program is Copyright (C) 1998-2001 martin HedenfaLk
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -200,7 +200,7 @@ void yafc_open(const char *host, unsigned int opt, const char *mech)
 		if(r == -1)
 			break;
 
-		if(gvConnectAttempts != -1 && i+1 < gvConnectAttempts) {
+		if(gvConnectAttempts == -1 || i+1 < gvConnectAttempts) {
 			ftp_set_close_handler();
 			fprintf(stderr, _("Sleeping %u seconds before connecting again (attempt #%d)...\n"),
 				   gvConnectWaitTime, i+2);
