@@ -1,7 +1,7 @@
 /* rc.c -- config file parser + autologin lookup
  * 
  * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998, 1999, 2000 Martin Hedenfalk
+ * This program is Copyright (C) 1998-2001 martin HedenfaLk
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -178,10 +178,12 @@ static void parse_host(int trig, FILE *fp)
 			if(!has_warned_about_passwd) {
 				struct stat sb;
 				has_warned_about_passwd = true;
-				if(fstat(fileno(fp), &sb)==0 && (sb.st_mode & 077)!=0)
+				if(fstat(fileno(fp), &sb)==0 && (sb.st_mode & 077)!=0) {
 					printf(_("WARNING! Config file contains passwords "
 							 "but is readable by others (mode %03o)\n"),
 						   sb.st_mode&0777);
+					sleep(3);
+				}
 			}
 
 		} else if(strcasecmp(e, "anonymous") == 0) {
